@@ -24,7 +24,12 @@ from commitizen.exceptions import (
 )
 from commitizen.changelog_formats import get_changelog_format
 from commitizen.providers import get_provider
-from commitizen.version_schemes import InvalidVersion, get_version_scheme
+from commitizen.version_schemes import (
+    get_version_scheme,
+    Increment,
+    InvalidVersion,
+    Prerelease,
+)
 
 logger = getLogger("commitizen")
 
@@ -47,6 +52,7 @@ class Bump:
                     "tag_format",
                     "prerelease",
                     "increment",
+                    "increment_mode",
                     "bump_message",
                     "gpg_sign",
                     "annotated_tag",
@@ -109,7 +115,7 @@ class Bump:
                 is_initial = questionary.confirm("Is this the first tag created?").ask()
         return is_initial
 
-    def find_increment(self, commits: list[git.GitCommit]) -> str | None:
+    def find_increment(self, commits: list[git.GitCommit]) -> Increment | None:
         # Update the bump map to ensure major version doesn't increment.
         is_major_version_zero: bool = self.bump_settings["major_version_zero"]
         # self.cz.bump_map = defaults.bump_map_major_version_zero
@@ -129,7 +135,7 @@ class Bump:
         )
         return increment
 
-    def __call__(self):  # noqa: C901
+    def __call__(self) -> None:  # noqa: C901
         """Steps executed to bump."""
         provider = get_provider(self.config)
 
@@ -146,12 +152,14 @@ class Bump:
 
         dry_run: bool = self.arguments["dry_run"]
         is_yes: bool = self.arguments["yes"]
-        increment: str | None = self.arguments["increment"]
-        prerelease: str | None = self.arguments["prerelease"]
+        increment: Increment | None = self.arguments["increment"]
+        prerelease: Prerelease | None = self.arguments["prerelease"]
         devrelease: int | None = self.arguments["devrelease"]
         is_files_only: bool | None = self.arguments["files_only"]
-        is_local_version: bool | None = self.arguments["local_version"]
+        is_local_version: bool = self.arguments["local_version"]
         manual_version = self.arguments["manual_version"]
+        build_metadata = self.arguments["build_metadata"]
+        increment_mode: str = self.arguments["increment_mode"]
 
         if manual_version:
             if increment:
@@ -168,6 +176,11 @@ class Bump:
                     "--local-version cannot be combined with MANUAL_VERSION"
                 )
 
+            if build_metadata:
+                raise NotAllowed(
+                    "--build-metadata cannot be combined with MANUAL_VERSION"
+                )
+
             if major_version_zero:
                 raise NotAllowed(
                     "--major-version-zero cannot be combined with MANUAL_VERSION"
@@ -184,27 +197,22 @@ class Bump:
                     f"--major-version-zero is meaningless for current version {current_version}"
                 )
 
+        if build_metadata:
+            if is_local_version:
+                raise NotAllowed(
+                    "--local-version cannot be combined with --build-metadata"
+                )
+
         current_tag_version: str = bump.normalize_tag(
             current_version,
             tag_format=tag_format,
             scheme=self.scheme,
         )
 
-        is_initial = self.is_initial_tag(current_tag_version, is_yes)
-        if is_initial:
-            commits = git.get_commits()
-        else:
-            commits = git.get_commits(current_tag_version)
-
         # If user specified changelog_to_stdout, they probably want the
         # changelog to be generated as well, this is the most intuitive solution
         self.changelog = self.changelog or bool(self.changelog_to_stdout)
 
-        # No commits, there is no need to create an empty tag.
-        # Unless we previously had a prerelease.
-        if not commits and not current_version.is_prerelease:
-            raise NoCommitsFoundError("[NO_COMMITS_FOUND]\n" "No new commits found.")
-
         if manual_version:
             try:
                 new_version = self.scheme(manual_version)
@@ -215,6 +223,19 @@ class Bump:
                 ) from exc
         else:
             if increment is None:
+                is_initial = self.is_initial_tag(current_tag_version, is_yes)
+                if is_initial:
+                    commits = git.get_commits()
+                else:
+                    commits = git.get_commits(current_tag_version)
+
+                # No commits, there is no need to create an empty tag.
+                # Unless we previously had a prerelease.
+                if not commits and not current_version.is_prerelease:
+                    raise NoCommitsFoundError(
+                        "[NO_COMMITS_FOUND]\n" "No new commits found."
+                    )
+
                 increment = self.find_increment(commits)
 
             # It may happen that there are commits, but they are not eligible
@@ -226,17 +247,14 @@ class Bump:
                     "To avoid this error, manually specify the type of increment with `--increment`"
                 )
 
-            # Increment is removed when current and next version
-            # are expected to be prereleases.
-            if prerelease and current_version.is_prerelease:
-                increment = None
-
             new_version = current_version.bump(
                 increment,
                 prerelease=prerelease,
                 prerelease_offset=prerelease_offset,
                 devrelease=devrelease,
                 is_local_version=is_local_version,
+                build_metadata=build_metadata,
+                exact_increment=increment_mode == "exact",
             )
 
         new_tag_version = bump.normalize_tag(
@@ -338,6 +356,7 @@ class Bump:
         if is_files_only:
             raise ExpectedExit()
 
+        # FIXME: check if any changes have been staged
         c = git.commit(message, args=self._get_commit_args())
         if self.retry and c.return_code != 0 and self.changelog:
             # Maybe pre-commit reformatted some files? Retry once
@@ -393,7 +412,7 @@ class Bump:
         else:
             out.success("Done!")
 
-    def _get_commit_args(self):
+    def _get_commit_args(self) -> str:
         commit_args = ["-a"]
         if self.no_verify:
             commit_args.append("--no-verify")
